var MorphologyHelpers_8h =
[
    [ "NearestNeighborBitMask&lt; di, dj, dk &gt;", "structnanovdb_1_1tools_1_1morphology_1_1NearestNeighborBitMask.html", "structnanovdb_1_1tools_1_1morphology_1_1NearestNeighborBitMask" ],
    [ "nanovdb::tools::morphology::NearestNeighbors", "namespacenanovdb_1_1tools_1_1morphology.html#a31d3cd59d1264144ae21e5250166cfc2", [
      [ "nanovdb::tools::morphology::NN_FACE", "namespacenanovdb_1_1tools_1_1morphology.html#a31d3cd59d1264144ae21e5250166cfc2a8b7234ad92f6feba2725d890a38fdd59", null ],
      [ "nanovdb::tools::morphology::NN_FACE_EDGE", "namespacenanovdb_1_1tools_1_1morphology.html#a31d3cd59d1264144ae21e5250166cfc2a6d84698cb77f59ae061433cbb1313bbf", null ],
      [ "nanovdb::tools::morphology::NN_FACE_EDGE_VERTEX", "namespacenanovdb_1_1tools_1_1morphology.html#a31d3cd59d1264144ae21e5250166cfc2a2cbda8f22b738858b06cb668117278ee", null ]
    ] ],
    [ "nanovdb::tools::morphology::neighborMaskStencil", "namespacenanovdb_1_1tools_1_1morphology.html#a57a574dad8a610bfdbbf5992a94f7087", null ]
];